DROP VIEW V_REPORT_TICKET
GO

CREATE VIEW V_REPORT_TICKET
AS
	SELECT 
		-- Infos TICKET
		TICKET.ID as TICKET_ID,
		TICKET.NATURE_OP as TICKET_NATURE_OP,
		TICKET.NUM_BALANCE as TICKET_BALANCE,
		TICKET.CODE as TICKET_CODE,
		TICKET.NATURE_OP + CAST(TICKET.NUM_BALANCE as VARCHAR) + '-' + CAST(TICKET.CODE as VARCHAR) as TICKET_IDENTIFICATION,
		TICKET.NB_COUVERTS as TICKET_COUVERTS,
		TICKET.STATUT as TICKET_STATUT,
		TICKET.DATE_TICKET as TICKET_DATE,
		DATEPART(hh, TICKET.DATE_TICKET) as TICKET_HEURE,
		DATEPART(mi, TICKET.DATE_TICKET) as TICKET_MINUTE,
		CASE WHEN TICKET.NATURE_OP in ('VT', 'BL', 'TH') THEN 'VENTE' WHEN TICKET.NATURE_OP in ('HV') THEN 'HORS_VENTE' ELSE 'AUTRE' END TICKET_TYPE_VENTE,
		CASE WHEN TICKET.STATUT in ('T','A','N') THEN 'O' ELSE 'N' END as TICKET_TERMINE,
		-- Infos VENDEUR
		VENDEUR.ID as VENDEUR_ID,
		VENDEUR.NOM as VENDEUR_NOM
	FROM
		TICKET	
			INNER JOIN VENDEUR ON TICKET.ID_VENDEUR = VENDEUR.ID
	WHERE
		TICKET.TOTAL - TICKET.MONTANT_REMISE <> 0
GO

DROP VIEW V_REPORT_TICKET_LIGNE 
GO

CREATE VIEW V_REPORT_TICKET_LIGNE 
AS
	SELECT 
		-- Infos TICKET
		TICKET.ID as TICKET_ID,
		TICKET.NATURE_OP as TICKET_NATURE_OP,
		TICKET.NUM_BALANCE as TICKET_BALANCE,
		TICKET.CODE as TICKET_CODE,
		TICKET.NATURE_OP + CAST(TICKET.NUM_BALANCE as VARCHAR) + '-' + CAST(TICKET.CODE as VARCHAR) as TICKET_IDENTIFICATION,
		TICKET.NB_COUVERTS as TICKET_COUVERTS,
		TICKET.STATUT as TICKET_STATUT,
		TICKET.DATE_TICKET as TICKET_DATE,
		DATEPART(hh, TICKET.DATE_TICKET) as TICKET_HEURE,
		DATEPART(mi, TICKET.DATE_TICKET) as TICKET_MINUTE,
		CASE WHEN TICKET.NATURE_OP in ('VT','BL','TH') THEN 'VENTE' WHEN TICKET.NATURE_OP in ('HV') THEN 'HORS_VENTE' ELSE 'AUTRE' END as TICKET_TYPE_VENTE,
		CASE WHEN TICKET.STATUT in ('T','A','N') THEN 'O' ELSE 'N' END as TICKET_TERMINE,
		-- Infos VENDEUR
		VENDEUR.ID as VENDEUR_ID,
		VENDEUR.NOM as VENDEUR_NOM,
		-- Infos LIGNE
		TICKET_LIGNE.QUANTITE as QTE,
		TICKET_LIGNE.MONTANT_HT as HT,
		TICKET_LIGNE.MONTANT_TVA as TVA,
		TICKET_LIGNE.MONTANT_HT + TICKET_LIGNE.MONTANT_TVA as TTC,
		TICKET_LIGNE.MENU as EST_FORMULE,
		TICKET_LIGNE.MENU_R as EST_MENU,
		CASE WHEN TICKET_LIGNE.ID_LIEN_MENU is not null THEN 'O' ELSE 'N' END as APPARTIENT_FORMULE,
		CASE WHEN TICKET_LIGNE.ID_LIEN_MENU_R is not null THEN 'O' ELSE 'N' END as APPARTIENT_MENU,
		TICKET_LIGNE.STATUT as TICKET_LIGNE_STATUT,
		TICKET_LIGNE.CONSIGNE as TICKET_LIGNE_CONSIGNE,
		-- Infos RAYON
		RAYON.ID as RAYON_ID,
		RAYON.INTITULE as RAYON_INTITULE,
		-- Infos FAMILLE
		FAMILLE.ID as FAMILLE_ID,
		FAMILLE.INTITULE as FAMILLE_INTITULE
	FROM
		TICKET	
			INNER JOIN TICKET_LIGNE ON TICKET.ID = TICKET_LIGNE.ID_TICKET
				INNER JOIN ARTICLE ON TICKET_LIGNE.ID_ARTICLE = ARTICLE.ID
					INNER JOIN RAYON ON ARTICLE.ID_RAYON = RAYON.ID
					INNER JOIN FAMILLE ON ARTICLE.ID_FAMILLE = FAMILLE.ID
			INNER JOIN VENDEUR ON TICKET.ID_VENDEUR = VENDEUR.ID
	WHERE
		TICKET.TOTAL - TICKET.MONTANT_REMISE <> 0 AND
		TICKET_LIGNE.ORCHREST IS NULL
GO

DROP VIEW V_REPORT_TICKET_PAIEMENT
GO

CREATE VIEW V_REPORT_TICKET_PAIEMENT
AS
	SELECT 
		-- Infos TICKET
		TICKET.ID as TICKET_ID,
		TICKET.NATURE_OP as TICKET_NATURE_OP,
		TICKET.NUM_BALANCE as TICKET_BALANCE,
		TICKET.CODE as TICKET_CODE,
		TICKET.NATURE_OP + CAST(TICKET.NUM_BALANCE as VARCHAR) + '-' + CAST(TICKET.CODE as VARCHAR) as TICKET_IDENTIFICATION,
		TICKET.NB_COUVERTS as TICKET_COUVERTS,
		TICKET.STATUT as TICKET_STATUT,
		TICKET.DATE_TICKET as TICKET_DATE,
		DATEPART(hh, TICKET.DATE_TICKET) as TICKET_HEURE,
		DATEPART(mi, TICKET.DATE_TICKET) as TICKET_MINUTE,
		CASE WHEN TICKET.NATURE_OP in ('VT','BL','TH') THEN 'VENTE' WHEN TICKET.NATURE_OP in ('HV') THEN 'HORS_VENTE' ELSE 'AUTRE' END as TICKET_TYPE_VENTE,
		CASE WHEN TICKET.STATUT in ('T','A','N') THEN 'O' ELSE 'N' END as TICKET_TERMINE,
		-- Infos VENDEUR
		VENDEUR.ID as VENDEUR_ID,
		VENDEUR.NOM as VENDEUR_NOM,
		-- Infos PAIEMENT
		MODE_PAIEMENT.ID as MODE_PAIEMENT_ID,
		MODE_PAIEMENT.CODE as MODE_PAIEMENT_CODE,
		MODE_PAIEMENT.INTITULE as MODE_PAIEMENT_INTITULE,
		TICKET_PAIEMENT.MONTANT as PAIEMENT_MONTANT,
		TICKET_PAIEMENT.TROP_PERCU as PAIEMENT_TROP_PERCU,
		CASE 
			WHEN TICKET_PAIEMENT.STATUT = 'N' AND TP_ORIGINE.ID_TICKET_PAIEMENT IS NOT NULL THEN 'O'
			WHEN TICKET_PAIEMENT.STATUT <> 'N' AND TICKET_PAIEMENT.ID_TICKET_PAIEMENT IS NOT NULL THEN 'O'
			ELSE 'N'
		END as PAIEMENT_RENDU_MONNAIE,
		TICKET_PAIEMENT.STATUT as PAIEMENT_STATUT
	FROM
		TICKET	
			INNER JOIN TICKET_PAIEMENT ON TICKET.ID = TICKET_PAIEMENT.ID_TICKET
				INNER JOIN MODE_PAIEMENT ON TICKET_PAIEMENT.ID_MODE_PAIEMENT = MODE_PAIEMENT.ID
				LEFT OUTER JOIN TICKET_PAIEMENT TP_ORIGINE ON TICKET_PAIEMENT.ID_TICKET_PAIEMENT = TP_ORIGINE.ID AND TICKET_PAIEMENT.STATUT = 'N'
			INNER JOIN VENDEUR ON TICKET.ID_VENDEUR = VENDEUR.ID
	WHERE
		TICKET.TOTAL - TICKET.MONTANT_REMISE <> 0
GO


SELECT * FROM V_REPORT_TICKET
GO

SELECT * FROM V_REPORT_TICKET_LIGNE
GO

SELECT * FROM V_REPORT_TICKET_PAIEMENT
GO

